@@ -38,8 +38,9 @@ pub(crate) struct Package {
     pub publish: bool,
 }
 
-#[derive(Serialize, Deserialize, Debug)]
+#[derive(Serialize, Deserialize, Default, Debug)]
 pub(crate) enum Edition {
+    #[default]
     #[serde(rename = "2015")]
     E2015,
     #[serde(rename = "2018")]
@@ -59,28 +60,12 @@ pub(crate) struct Bin {
 #[derive(Serialize, Clone, Debug)]
 pub(crate) struct Name(pub String);
 
-#[derive(Serialize, Debug)]
-pub(crate) struct Config {
-    pub build: Build,
-}
-
-#[derive(Serialize, Debug)]
-pub(crate) struct Build {
-    pub rustflags: Vec<&'static str>,
-}
-
 #[derive(Serialize, Debug)]
 pub(crate) struct Workspace {
     #[serde(skip_serializing_if = "Map::is_empty")]
     pub dependencies: Map<String, Dependency>,
 }
 
-impl Default for Edition {
-    fn default() -> Self {
-        Edition::E2018
-    }
-}
-
 impl AsRef<OsStr> for Name {
     fn as_ref(&self) -> &OsStr {
         self.0.as_ref()
